function Par = modelsetup(condition,latency,salience,vSep,outputname)
global Par


% condition 1 = one target
% condition 2 = two targets same location
% condition 3 = two targets different side
% condition 4 = two targets different side, simultaneous
% condition 5 = two targets different location, same side simultaneous
% condition 6 = two targets different location, same side sequential

%latency = latency between two targets in ms
%salience = visual strength of targets (1.0 = normal)
%vSep = vertical separation when two targets are on the same side in different locations
%outputname = string indicating the name of the data file output

%Latek code for inhibition formula
%  I_{(j,t)} = \left [ A_{(k,t)} - \theta \right ]_{0} * \frac{Inhib}{dist(j,k)^2}

Par.condition = condition;
Par.masking = 1;

%size of the visual map, in degrees
Par.xdim = 27;
Par.ydim = 27;

Par.AMFloorval = 1.0;
Par.AMCeilval = 2.5;  %instead of 2.5

%These store the current activation levels of all neurons
%in this code, V1 = EV from the paper, and IT = LV
Par.V1 = zeros(Par.xdim,Par.ydim);
Par.IT = zeros(Par.xdim,Par.ydim);
Par.AM = zeros(Par.xdim,Par.ydim);

AMnoise = 0;

%excitatory synaptic strength
Par.ITtoAM = .005;
Par.V1toIT = .0091;

%how big are the receptive fields in IT?  (2 nodes = + and - 1 degrees or a total of 3 degrees diameter)
Par.RFsize = 2;

%total simulation length
Par.steps = 2000;  %2 seconds

%history of the simulation
Par.V1History = zeros(Par.xdim,Par.ydim,Par.steps);
Par.ITHistory = zeros(Par.xdim,Par.ydim,Par.steps);
Par.AMHistory = zeros(Par.xdim,Par.ydim,Par.steps);

%timestep of T1 & T2 onset
Par.t1onset = 1165;
Par.t2onset = Par.t1onset + latency;  %120ms later
if (condition ==4 | condition ==5)   %conditions 4 and 5 are simultaneous targets
    Par.t2onset = Par.t1onset;
end

Par.latency = latency;
Par.Vsep = vSep;  %vertical separation between T1 and T2 when on same side
Par.tduration = 120;
Par.Hsep = 6;  %how far are they separated horizontally?

%x/y location of the two targets.
Par.loc1y = ceil(Par.ydim/2)-7;
Par.loc2y = ceil(Par.ydim/2)-7;
Par.loc1x = ceil(Par.xdim/2)-Par.Hsep; %left side
Par.loc2x = ceil(Par.xdim/2)+Par.Hsep;  % right side

if(Par.condition ==2| Par.condition ==5| Par.condition ==6)   %put T2 on same side as T1
    Par.loc2x = ceil(Par.xdim/2)-Par.Hsep;
end

if( Par.condition ==5| Par.condition ==6)   %change vertical position of T2
    Par.loc2y = ceil(Par.ydim/2)-7 + Par.Vsep;
end


%this controls the rate of change of neurons
Par.dt_vm = .015;
%reversal potentials of the neurons: excitatory, Leak and inhibitory
Par.EE = 30;
Par.EL = 0;
Par.EI = -10;

%magnitude of localized attentional interference and threshold at which it
%begins
Par.LAI = 64;  %strength of localized inhibition in the AM
Par.Thresh = 5;  %threshold for attentional amplification
Par.ThreshI = 6;   %threshold for suppression surrounding region
attentionweight = 10;  %magnitude of attentional amplification

for(step = 1: Par.steps)
    
    Par.V1excite = zeros(Par.xdim,Par.ydim);
    Par.V1inhib= zeros(Par.xdim,Par.ydim);
    
    lag1samelocation = 0;
    
    if(condition ==2)  %same location condition
        if (step > Par.t2onset & step < Par.t2onset + Par.tduration)
            lag1samelocation = 1;  %special case for when the T2 serves as the T1 mask
        end
    end
    
    %is T1 on screen?
    if( step >=Par.t1onset & step <Par.t1onset + Par.tduration)
        Par.V1excite(Par.loc1x,Par.loc1y) = salience;
    else
        if(Par.masking & step > Par.t1onset + Par.tduration)  %the time for the mask has arrived
            if step < (Par.t1onset + Par.tduration*2) & lag1samelocation == 0;  
                Par.V1inhib(Par.loc1x,Par.loc1y) = 1;
            end
        end
    end
    
    %is T2 on screen?
    if( step>= Par.t2onset & step <Par.t2onset + Par.tduration)
        if(Par.condition >1)   %only insert the T2 if condition is 2 or more
            Par.V1excite(Par.loc2x,Par.loc2y) = salience;
        end
    end
    if(Par.masking & step > Par.t2onset + Par.tduration)
        
       if step < (Par.t2onset + Par.tduration*2) & condition > 1 %apply masking after T1 if necessary
            Par.V1inhib(Par.loc2x,Par.loc2y) = 1;
        end
    end
    %feed forward activity from V1 to IT and AM
    
    %step through each neuron in these layers
    for(x = 1: Par.xdim)
        for(y = 1: Par.ydim)
            
            xmin = max(x- Par.RFsize ,1);
            xmax = min(x+ Par.RFsize ,Par.xdim);
            ymin = max(y- Par.RFsize ,1);
            ymax = min(y+ Par.RFsize ,Par.ydim);
            Par.ITexcite(x,y) = 0;
            Par.AMexcite(x,y) = 0;
            
            %gather input from all the neurons within their receptive field
            for(x2 = xmin:xmax);
                for(y2 = ymin:ymax)
                    if(Par.AM(x2,y2) > Par.Thresh)
                        attention = log(Par.AM(x2,y2) - Par.Thresh+1)*attentionweight;
                    else
                        attention = 1;
                    end
                    if (Par.V1(x2,y2) >0 )
                        Par.ITexcite(x,y) =  Par.ITexcite(x,y) +Par.V1(x2,y2)*Par.V1toIT *attention;
                    end
                    
                    if (Par.IT(x2,y2) >0 )
                        Par.AMexcite(x,y) =  Par.AMexcite(x,y) + Par.IT(x2,y2)*Par.ITtoAM;
                    end
                end
            end
        end
    end
    
    %compute whether any nodes in the attention map have crossed threshold
    %and apply inhibition
    
    Par.AMinhib = zeros(Par.xdim,Par.ydim);

    for(x = 1: Par.xdim)
        for(y = 1: Par.ydim)
            if(Par.AM(x,y)>Par.ThreshI)
                xmin = max(x- Par.RFsize*3 ,1);
                xmax = min(x+ Par.RFsize*3 ,Par.xdim);
                ymin = max(y- Par.RFsize*3 ,1);
                ymax = min(y+ Par.RFsize*3 ,Par.ydim);
                
                
                for(x2 = xmin:xmax);
                    for(y2 = ymin:ymax)
                        if(x2 ~=x | y2~=y)
                            
                            distance = sqrt((x-x2)^2 + (y-y2)^2)+1;
                            if(distance < 7 )
                                Par.AMinhib(x2,y2) = Par.AMinhib(x2,y2)+max(0,(Par.AM(x,y)-Par.ThreshI)) * Par.LAI/ ((distance^2)) ;
                            end
                        end
                    end
                end
            end
        end
    end
    %compute the activation values of all the nodes
    
    for(x = 1: Par.xdim)
        for(y = 1: Par.ydim)
            Par.ITexcite(x,y) = Par.dt_vm* (Par.EE-Par.IT(x,y)) * Par.ITexcite(x,y);
            Par.AMexcite(x,y) = Par.dt_vm * (Par.EE-Par.AM(x,y)) * Par.AMexcite(x,y);
            Par.V1excite(x,y) = Par.dt_vm* (Par.EE-Par.V1(x,y)) * Par.V1excite(x,y);
            Par.V1leak(x,y) =  Par.dt_vm* (Par.EL- Par.V1(x,y));
            Par.ITleak(x,y) =  Par.dt_vm* (Par.EL- Par.IT(x,y));
            Par.AMleak(x,y) =  Par.dt_vm* (Par.EL- Par.AM(x,y));
            Par.AMinhib(x,y) = Par.dt_vm * (Par.EI-Par.AM(x,y)) * Par.AMinhib(x,y);
            Par.V1inhib(x,y) = Par.dt_vm * (Par.EI-Par.V1(x,y)) * Par.V1inhib(x,y);
            
            Par.ITinhib(x,y) = 0;
            Par.V1(x,y) = max(Par.EI,Par.V1(x,y) + Par.V1excite(x,y) +  Par.V1inhib(x,y) + Par.V1leak(x,y));
            Par.IT(x,y) = max(Par.EI,Par.IT(x,y) + Par.ITexcite(x,y) +  Par.ITinhib(x,y) + Par.ITleak(x,y));
            Par.AM(x,y) = max(Par.EI,Par.AM(x,y) + Par.AMexcite(x,y) +  Par.AMinhib(x,y) + Par.AMleak(x,y) + rand*AMnoise-rand*AMnoise/2);
            
            Par.AMHistory(x,y,step) = Par.AM(x,y);
            Par.ITHistory(x,y,step) = Par.IT(x,y);
            Par.V1History(x,y,step) = Par.V1(x,y);
            
            %compute the N2pc
            FlooredAM = max(Par.AMFloorval,Par.AM);
            FlooredAM = min(Par.AMCeilval,FlooredAM);
            
            Par.N2pc(step) = sum(sum(FlooredAM(1:ceil(Par.xdim/2)-1,:)));% -  sum(sum(FlooredAM(ceil(Par.xdim/2)+1:Par.xdim),:));
            Par.N2pc(step) = Par.N2pc(step) -sum(sum(FlooredAM(ceil(Par.xdim/2)+1:Par.xdim,:)));
            
        end
    end
    %used to track when the difference between two datapoints first emerges
    Par.diffHistoryV1(step) = Par.V1(Par.loc1x,Par.loc1y)- Par.V1(Par.loc2x,Par.loc2y);
    Par.diffHistoryIT(step) = Par.IT(Par.loc1x,Par.loc1y)- Par.IT(Par.loc2x,Par.loc2y);
    Par.diffHistoryAM(step) = Par.AM(Par.loc1x,Par.loc1y)- Par.AM(Par.loc2x,Par.loc2y);
    
end

%reduce the sampling rate of the N2pc by a factor of 4

decimate = 4;

clear Par.smallN2pc
count = 0;
for(i = decimate: decimate:length(Par.N2pc)-decimate)
    count = count + 1;
    Par.smallN2pc(count) = mean(Par.N2pc(i-decimate/2:i+decimate/2));
end

%ouput it to disk. 
Par.N2pc = Par.smallN2pc;
csvwrite(sprintf('%s.csv',outputname),Par.smallN2pc);


